# Tests by default. No tests: rpm -ba --define 'dotests 0' *.spec
%{!?dotests: %define dotests 1}

Summary: An SSL-encrypting socket wrapper
Name: stunnel
Version: 5.59
Release: 1
License: GPLv2
Group: Applications/Internet
URL: http://stunnel.mirt.net/
Source0: ftp://ftp.stunnel.org/stunnel//stunnel-%{version}.tar.gz
Source1: ftp://stunnel.mirt.net/stunnel/%{name}-%{version}.tar.gz.asc
Source2: ftp://stunnel.mirt.net/stunnel/%{name}-%{version}.tar.gz.sha256
Source3: Certificate-Creation
Source4: sfinger.xinetd
Source5: stunnel-sfinger.conf
Source6: pop3-redirect.xinetd
Source7: stunnel-pop3s-client.conf
Patch0: %{name}-5.59-authpriv.patch
Patch10: %{name}-5.59-aix.patch
Patch11: stunnel-5.59-test.patch

%define _libdir64 %{_prefix}/lib64

Requires: libgcc >= 8.3.0-1
BuildRequires: patch >= 2.7.6-1
BuildRequires: pkg-config, sed, perl >= 5.28.1-1

%ifos aix5.1
Requires: AIX-rpm < 5.2.0.0, prngd
%else
Requires: AIX-rpm >= 6.1.0.0
%endif

%description
Stunnel is a socket wrapper which can provide SSL (Secure Sockets
Layer) support to ordinary applications. For example, it can be used
in conjunction with imapd to create an SSL secure IMAP server.

%prep
%setup -q
export PATH=/opt/freeware/bin:$PATH
%patch0 -p1 -b .authpriv
%patch10
%patch11



# Duplicate source for 32 & 64 bits
rm -rf   /tmp/%{name}-%{version}-32bit
cp -pr . /tmp/%{name}-%{version}-32bit
rm -fr *
mv       /tmp/%{name}-%{version}-32bit 32bit
cp -pr 32bit 64bit


%build
export PATH=/opt/freeware/bin:$PATH
cd 64bit
export OBJECT_MODE=64
export CONFIG_SHELL=/opt/freeware/bin/bash
export CONFIG_ENV_ARGS=/opt/freeware/bin/bash
export CC="/opt/freeware/bin/gcc  -maix64 -O2"
export LDFLAGS="-L/opt/freeware/lib64 -L/opt/freeware/lib  -Wl,-blibpath:/opt/freeware/lib64:/opt/freeware/lib:/usr/lib:/lib  -lpthread "
./configure \
    --prefix=%{_prefix} \
    --mandir=%{_mandir} \
    --libdir=%{_libdir64} \
    --localstatedir=/var \
    --enable-ipv6 \
    --disable-systemd \
%ifos aix5.1
    --with-egd-socket=/dev/egd-pool \
%else
    --with-random=/dev/urandom \
%endif
    --with-ssl=/usr

## get rid of pesky "-pthread" flag
/opt/freeware/bin/sed -i 's|-pthread||g' config.status

gmake %{?_smp_mflags} V=1

if [ "%{dotests}" == 1 ]
then
   (gmake -k check || true)
fi


cd ../32bit
export OBJECT_MODE=32
export CC="/opt/freeware/bin/gcc  -maix32 -O2   -D_LARGE_FILES"
export LDFLAGS=" -L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000  -lpthread "

./configure \
    --prefix=%{_prefix} \
    --mandir=%{_mandir} \
    --libdir=%{_libdir} \
    --localstatedir=/var \
    --enable-ipv6 \
    --disable-systemd \
%ifos aix5.1
    --with-egd-socket=/dev/egd-pool \
%else
    --with-random=/dev/urandom \
%endif
    --with-ssl=/usr

## get rid of pesky "-pthread" flag
/opt/freeware/bin/sed -i 's|-pthread||g' config.status
gmake %{?_smp_mflags} V=1
if [ "%{dotests}" == 1 ]
      then
          (gmake -k check || true)
      fi
export AR="ar -X32_64"
# add the 64-bit shared objects to the shared library containing already the
# 32-bit shared objects
${AR} -q  src/.libs/libstunnel.a ../64bit/src/.libs/libstunnel.so

%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}
export PATH=/opt/freeware/bin:$PATH


cd 64bit
export OBJECT_MODE=64
export AR="/usr/bin/ar -X64"
gmake DESTDIR=${RPM_BUILD_ROOT} install
/usr/bin/strip ${RPM_BUILD_ROOT}%{_bindir}/* || :

mkdir -p ${RPM_BUILD_ROOT}%{_sysconfdir}/%{name}
touch ${RPM_BUILD_ROOT}%{_sysconfdir}/%{name}/%{name}.pem
(
  cd ${RPM_BUILD_ROOT}%{_bindir}
  for f in $(ls -1| grep -v -e _32 -e _64)
  do
     mv ${f} ${f}_64
  done
)


for lang in pl ; do
    mkdir -p ${RPM_BUILD_ROOT}%{_mandir}/${lang}/man8
    mv ${RPM_BUILD_ROOT}%{_mandir}/man8/*.${lang}.8* ${RPM_BUILD_ROOT}%{_mandir}/${lang}/man8/
done

mkdir srpm-docs
cp %{SOURCE3} %{SOURCE4} %{SOURCE5} %{SOURCE6} %{SOURCE7} srpm-docs
    

cd ../32bit
export OBJECT_MODE=32
export AR="/usr/bin/ar -X32"
gmake DESTDIR=${RPM_BUILD_ROOT} install
/usr/bin/strip ${RPM_BUILD_ROOT}%{_bindir}/* || :
(
  cd ${RPM_BUILD_ROOT}%{_bindir}
  for f in $(ls -1| grep -v -e _32 -e _64)
  do
    mv ${f} ${f}_32
    ln -sf ${f}_64 ${f}
  done
)

%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,system)
%doc 32bit/AUTHORS.md 32bit/BUGS.md 32bit/COPY* 32bit/CREDITS.md 32bit/PORTS.md 32bit/README.md 32bit/TODO.md
%doc 32bit/tools/stunnel.conf-sample
#%doc 32bit/srpm-docs/*
#%lang(en) %doc doc/en/*
#%lang(po) %doc doc/pl/*
%{_bindir}/*
%{_libdir}/stunnel/*.a
%{_mandir}/man8/*
%lang(pl) %{_mandir}/pl/man8/*
%dir %{_sysconfdir}/%{name}
%dir /var/lib/%{name}


%changelog
* Fri Oct 22 2021 Reshma V Kumar <reskumar@in.ibm.com> - 5.59-1
- Update to version 5.59

* Tue Feb 04 2020 Rishita Saha <risaha16@in.ibm.com> - 5.56-1
- Updated to version 5.56

* Mon Nov 12 2018 Harshita Jain <harjain9@in.ibm.com> - 5.49-1
- Updated to version 5.49

* Wed Jul 11 2018 Michael Perzl <michael@perzl.org> - 5.48-1
- updated to version 5.48

* Thu Nov 17 2016 Michael Perzl <michael@perzl.org> - 5.36-2
- rebuilt against updated OpenSSL library

* Mon Oct 10 2016 Michael Perzl <michael@perzl.org> - 5.36-1
- updated to version 5.36

* Mon Oct 10 2016 Michael Perzl <michael@perzl.org> - 5.31-1
- updated to version 5.31





